@@ -110,7 +110,7 @@ ASSERTION = TypeVar('ASSERTION', bound=AbstractAssertion)
 
 class BinaryAssertion(AbstractAssertion[ACTUAL_TYPE]):
     def be(self, expected: any) -> bool:
-        return self._test_sequence(lambda actual: actual == expected, lambda: f" to be {Format.param(expected)}")
+        return self._test_sequence(lambda actual: actual == expected, lambda: f"to be {Format.param(expected)}")
 
 
 class QuantityAssertion(BinaryAssertion[ACTUAL_TYPE]):
@@ -118,45 +118,45 @@ class QuantityAssertion(BinaryAssertion[ACTUAL_TYPE]):
         return self.__class__(
             parent=self,
             actual_supplier=lambda: mapper(self._actual_supplier()),
-            name_supplier=lambda: "mapped",
+            name_supplier=lambda: f"mapped ",
         )
 
     def not_be(self, expected: any) -> bool:
-        return self._test_sequence(lambda actual: actual != expected, lambda: f" not to be {Format.param(expected)}")
+        return self._test_sequence(lambda actual: actual != expected, lambda: f"not to be {Format.param(expected)}")
 
     def between(self, lower: Number, higher: Number):
         return BinaryAssertion(
             parent=self,
             actual_supplier=lambda: lower <= self._actual_supplier() <= higher,
-            name_supplier=lambda: f"between {Format.param(lower)} and {Format.param(higher)}",
+            name_supplier=lambda: f"between {Format.param(lower)} and {Format.param(higher)} ",
         )
 
     def greater_than(self, expected: Number):
         return BinaryAssertion(
             parent=self,
             actual_supplier=lambda: self._actual_supplier() > expected,
-            name_supplier=lambda: f"greater than {Format.param(expected)}",
+            name_supplier=lambda: f"greater than {Format.param(expected)} ",
         )
 
     def lower_than(self, expected: Number):
         return BinaryAssertion(
             parent=self,
             actual_supplier=lambda: self._actual_supplier() < expected,
-            name_supplier=lambda: f"lower than {Format.param(expected)}",
+            name_supplier=lambda: f"lower than {Format.param(expected)} ",
         )
 
     def greater_equal_than(self, expected: Number):
         return BinaryAssertion(
             parent=self,
             actual_supplier=lambda: self._actual_supplier() >= expected,
-            name_supplier=lambda: f"greater equal than {Format.param(expected)}",
+            name_supplier=lambda: f"greater equal than {Format.param(expected)} ",
         )
 
     def lower_equal_than(self, expected: Number):
         return BinaryAssertion(
             parent=self,
             actual_supplier=lambda: self._actual_supplier() <= expected,
-            name_supplier=lambda: f"lower equal than {Format.param(expected)}",
+            name_supplier=lambda: f"lower equal than {Format.param(expected)} ",
         )
 
 
@@ -165,21 +165,21 @@ class StringAssertion(QuantityAssertion[str]):
         return BinaryAssertion(
             parent=self,
             actual_supplier=lambda: str(self._actual_supplier()).startswith(expected),
-            name_supplier=lambda: f"starts with {Format.param(expected)}",
+            name_supplier=lambda: f"starts with {Format.param(expected)} ",
         )
 
     def ends_with(self, expected: str):
         return BinaryAssertion(
             parent=self,
             actual_supplier=lambda: str(self._actual_supplier()).endswith(expected),
-            name_supplier=lambda: f"ends with {Format.param(expected)}",
+            name_supplier=lambda: f"ends with {Format.param(expected)} ",
         )
 
     def contains(self, expected: str):
         return BinaryAssertion(
             parent=self,
             actual_supplier=lambda: str(self._actual_supplier()).find(expected) >= 0,
-            name_supplier=lambda: f"contains {Format.param(expected)}",
+            name_supplier=lambda: f"contains {Format.param(expected)} ",
         )
 
     def matches(self, regex: str | re.Pattern):
@@ -189,7 +189,7 @@ class StringAssertion(QuantityAssertion[str]):
         return BinaryAssertion(
             parent=self,
             actual_supplier=lambda: regex.search(self._actual_supplier()) is not None,
-            name_supplier=lambda: f"matches {Format.param(regex.pattern)}",
+            name_supplier=lambda: f"matches {Format.param(regex.pattern)} ",
         )
 
     def has_words(self, *words: any):
@@ -199,7 +199,7 @@ class StringAssertion(QuantityAssertion[str]):
         return BinaryAssertion(
             parent=self,
             actual_supplier=lambda: regex.search(self._actual_supplier()) is not None,
-            name_supplier=lambda: f"has words {Format.param(pattern)}",
+            name_supplier=lambda: f"has words {Format.param(pattern)} ",
         )
 
     @property
@@ -207,7 +207,7 @@ class StringAssertion(QuantityAssertion[str]):
         return QuantityAssertion(
             parent=self,
             actual_supplier=lambda: len(self._actual_supplier()),
-            name_supplier=lambda: f"length {Format.param(len(self._actual_supplier()))}",
+            name_supplier=lambda: f"length {Format.param(len(self._actual_supplier()))} ",
         )
 
 
